@@ -23,10 +23,7 @@ class Storage(driver.Base):
         
     def _init_path(self, path=None):
         if path:
-            if path.startswith('/'):
-                path = path[1:]
-            if path.endswith('/'):
-                path = path[:-1]
+            path.split("/")[2]
         return path
 
     def content_redirect_url(self, path):
